

local function makeStar(N, r1, r2)
	local vertices = {{0,0}}
	for i = 0, N*2-1 do
		local a = math.pi/N*i
		local x = math.cos(a)
		local y = math.sin(a)
		local r = (i % 2) == 0 and r1 or r2
		table.insert(vertices, {x*r, y*r})
	end
	table.insert(vertices, vertices[2])
	return love.graphics.newMesh(vertices, "fan")
end

local star
local canvas
local downscale = 8

-- Canvas size
local cw, ch

function love.load()
	local w, h = love.graphics.getPixelDimensions()
	
	-- Calculate size of downscaled picture.
	-- Use ceil to round to the next larger number.
	-- This is necessary for the following reasons:
	--	- The upscaled canvas should not be larger than the window
	--	- The size of the large pixels should be an integer multiple of
	--		small pixels so that all large pixels end up the same size
	cw, ch =
		math.ceil(w/downscale),
		math.ceil(h/downscale)
	
	star = makeStar(5, 10, 20)
	
	-- Create a canvas to draw the image to.
	canvas = love.graphics.newCanvas(
		cw, ch,
		-- Use MSAA if you want to get nice edges
		-- If you want the rough staircase use msaa = 0 instead.
		{msaa=4}
	)
	-- Set canvas filter to nearest so the image gets pixelated and not blurred
	canvas:setFilter("nearest", "nearest")
end

function love.draw()
	-- Set the canvas to draw to
	love.graphics.setCanvas(canvas)
	-- The canvas needs to be cleared explicitly
	love.graphics.clear(.5, .5, 1)
	
	-- Draw some stuff
	love.graphics.push()
	love.graphics.translate(cw/2, ch/2)
	local t = love.timer.getTime()
	love.graphics.translate(0, ch/2-20-math.abs(math.sin(t*2))*ch/2)
	love.graphics.scale(math.sin(t*7)*.15+1)
	love.graphics.rotate(t)
	love.graphics.setColor(1, 1, .3)
	love.graphics.draw(star)
	love.graphics.pop()
	
	-- Stop drawing to the canvas
	love.graphics.setCanvas()
	
	-- Color must be set to white while drawing canvas or else
	-- the whole image will be tinted.
	love.graphics.setColor(1,1,1)
	
	-- Draw the (magnified) canvas to the screen
	love.graphics.push()
	love.graphics.scale(downscale)
	love.graphics.draw(canvas)
	love.graphics.pop()
end
